#!/usr/bin/env python
#   Reports the root to tip distance for an ultrametric tree

import sys
from dendropy import DataSet
import StringIO

def simple_test_tree():
    from dendropy import treegen
    t = treegen.pure_kingman(treegen.random_taxa_block(10))
    sys.stdout.write(t.compose_newick() + "\n")


if __name__ == '__main__':

    from optparse import OptionParser
    parser = OptionParser()
    parser.add_option("--nexus", dest="schema", action="store_const", const="NEXUS", default="NEWICK",
        help="Tree is in NEXUS.")
    (options, args) = parser.parse_args()

    if len(args) > 1:
        sys.exit("At most one argument (a newick tree string with branch lengths) can be specified")
    if len(args) == 1:
        s = open(args[0], 'rU')
    else:
        newick = sys.stdin.read()
        s = StringIO.StringIO(newick)

    d = DataSet()
    
    d.read(s, schema=options.schema, rooted=True)
    #if len(d.tree_lists) == 0:
    #    sys.exit("No trees found in file.")
    for tb in d.tree_lists:
        for tree in tb:
            tree.suppress_outdegree_one_nodes()
            tree.write(sys.stdout, schema=options.schema)


